bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOToGaussianGammaARD.lower_bound_contribution
================================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOToGaussianGammaARD.lower_bound_contribution